<?php
/**
 * niftygoodies functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package niftygoodies
 */

if ( ! function_exists( 'niftygoodies_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function niftygoodies_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on niftygoodies, use a find and replace
		 * to change 'niftygoodies' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'niftygoodies', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary', 'niftygoodies' ),
		) );


		//Social Menus

		add_action( 'init', 'my_register_nav_menus' );

		function my_register_nav_menus() {
    	register_nav_menu( 'social', __( 'Social', 'niftygoodies' ) );
		}

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'niftygoodies_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'niftygoodies_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function niftygoodies_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'niftygoodies_content_width', 640 );
}
add_action( 'after_setup_theme', 'niftygoodies_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function niftygoodies_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'niftygoodies' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'niftygoodies' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'niftygoodies_widgets_init' );

//ENQUEUE SCRIPTS AND STYLES.

function niftygoodies_scripts() {

	wp_enqueue_style( 'niftygoodies-style', get_stylesheet_uri() );
	wp_enqueue_style( 'niftygoodies-app-css',  get_template_directory_uri() .'/assets/css/app.css', array(), 1.2, 'all' );
	wp_enqueue_style( 'niftygoodies-bundle-css',  get_template_directory_uri() .'/assets/css/bundle.min.css', array(), 1.0, 'all' );
	
	wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/assets/js/all.js', array('jquery'), '1.0', true );
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
	add_action( 'wp_enqueue_scripts', 'niftygoodies_scripts' );

//IMPLEMENT THE CUSTOM HEADER FEATURE.

require get_template_directory() . '/inc/custom-header.php';


//CUSTOM TEMPLATE TAGS FOR THIS THEME.

require get_template_directory() . '/inc/template-tags.php';


//FUNCTIONS WHICH ENHANCE THE THEME BY HOOKING INTO WORDPRESS.

require get_template_directory() . '/inc/template-functions.php';


//CUSTOMIZER ADDITIONS.

require get_template_directory() . '/inc/customizer.php';

//WALKER NAV

require get_template_directory() . '/inc/bootstrap-navwalker.php';

//LOAD JETPACK COMPATIBILITY FILE

if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

//LOAD WOOCOMMERCE COMPATIBILITY FILE.
 
if ( class_exists( 'WooCommerce' ) ) {
	require get_template_directory() . '/inc/woocommerce.php';
}

//EDITOR STYLES

function wpdocs_theme_add_editor_styles() {
    add_editor_style( 'custom-editor-style.css' );
}
add_action( 'admin_init', 'wpdocs_theme_add_editor_styles' );

function niftygoodies_short_excerpt($excerpt){
	if ( !is_admin() ) {
	$limit = 200;

	if (strlen($excerpt) > $limit) {
		return substr($excerpt, 0, strpos($excerpt, ' ', $limit)) . '<p>' . '<a class="more-link" href="' . esc_url(get_permalink()) . '">' . esc_html('Read the full article','niftygoodies') . '</a></p>';
	} 

	return $excerpt;
	}
}
	add_filter('the_excerpt', 'niftygoodies_short_excerpt');
	
//BLOCK COLOR PALLETES
function niftygoodies_theme_supported_features() {
	add_theme_support( 'editor-color-palette', array(
		array(
			'name' => __( 'strong magenta', 'niftygoodies' ),
			'slug' => 'strong-magenta',
			'color' => '#a156b4',
			),
		array(
			'name' => __( 'light grayish magenta', 'niftygoodies' ),
			'slug' => 'light-grayish-magenta',
			'color' => '#d0a5db',
			),
		array(
			'name' => __( 'very light gray', 'niftygoodies' ),
			'slug' => 'very-light-gray',
			'color' => '#eee',
			),
		array(
			'name' => __( 'very dark gray', 'niftygoodies' ),
			'slug' => 'very-dark-gray',
			'color' => '#444',
			),
		) );
	}
	
add_action( 'after_setup_theme', 'niftygoodies_theme_supported_features' );